git@vger.kernel.org mailing list mirror (one of many)
 help / color / mirror / code / Atom feed
From: "Johannes Schindelin via GitGitGadget" <gitgitgadget@gmail.com>
To: git@vger.kernel.org
Cc: Johannes Schindelin <johannes.schindelin@gmx.de>,
	Johannes Schindelin <johannes.schindelin@gmx.de>
Subject: [PATCH 1/4] t5411: start using the default branch name "main"
Date: Tue, 27 Oct 2020 22:58:04 +0000	[thread overview]
Message-ID: <f997166db4c29d971a2343f70c9d9a0505a8cc4b.1603839487.git.gitgitgadget@gmail.com> (raw)
In-Reply-To: <pull.760.git.1603839487.gitgitgadget@gmail.com>

From: Johannes Schindelin <johannes.schindelin@gmx.de>

This is a straight-forward search-and-replace in the test script;
However, this is not yet complete because it requires many more
replacements in `t/t5411/`, too many for a single patch (the Git mailing
list rejects mails larger than 100kB). For that reason, we disable this
test script temporarily via the `PREPARE_FOR_MAIN_BRANCH` prereq.

Signed-off-by: Johannes Schindelin <johannes.schindelin@gmx.de>
---
 t/t5411-proc-receive-hook.sh | 19 ++++++++++++-------
 1 file changed, 12 insertions(+), 7 deletions(-)

diff --git a/t/t5411-proc-receive-hook.sh b/t/t5411-proc-receive-hook.sh
index 746487286f..06bbb02ed2 100755
--- a/t/t5411-proc-receive-hook.sh
+++ b/t/t5411-proc-receive-hook.sh
@@ -7,11 +7,16 @@ test_description='Test proc-receive hook'
 
 . ./test-lib.sh
 
+test_have_prereq PREPARE_FOR_MAIN_BRANCH || {
+	test_skip="In transit for the default branch name 'main'"
+	test_done
+}
+
 . "$TEST_DIRECTORY"/t5411/common-functions.sh
 
 setup_upstream_and_workbench () {
 	# Refs of upstream : master(A)
 	# Refs of workbench: master(A)  tags/v123
 	test_expect_success "setup upstream and workbench" '
 		rm -rf upstream.git &&
 		rm -rf workbench &&
@@ -25,10 +30,10 @@ setup_upstream_and_workbench () {
 			git config core.abbrev 7 &&
 			git tag -m "v123" v123 $A &&
 			git remote add origin ../upstream.git &&
-			git push origin master &&
-			git update-ref refs/heads/master $A $B &&
+			git push origin main &&
+			git update-ref refs/heads/main $A $B &&
 			git -C ../upstream.git update-ref \
-				refs/heads/master $A $B
+				refs/heads/main $A $B
 		) &&
 		TAG=$(git -C workbench rev-parse v123) &&
 
@@ -99,8 +104,8 @@ start_httpd
 # Re-initialize the upstream repository and local workbench.
 setup_upstream_and_workbench
 
 # Refs of upstream : master(A)
 # Refs of workbench: master(A)  tags/v123
 test_expect_success "setup for HTTP protocol" '
 	git -C upstream.git config http.receivepack true &&
 	upstream="$HTTPD_DOCUMENT_ROOT_PATH/upstream.git" &&
@@ -7,11 +7,16 @@ test_description='Test proc-receive hook'
 
 setup_upstream_and_workbench () {
-	# Refs of upstream : master(A)
-	# Refs of workbench: master(A)  tags/v123
+	# Refs of upstream : main(A)
+	# Refs of workbench: main(A)  tags/v123
 	test_expect_success "setup upstream and workbench" '
 		rm -rf upstream.git &&
@@ -99,8 +104,8 @@ start_httpd
 setup_upstream_and_workbench
 
-# Refs of upstream : master(A)
-# Refs of workbench: master(A)  tags/v123
+# Refs of upstream : main(A)
+# Refs of workbench: main(A)  tags/v123
 test_expect_success "setup for HTTP protocol" '
 	git -C upstream.git config http.receivepack true &&
-- 
gitgitgadget


  reply	other threads:[~2020-10-27 22:58 UTC|newest]

Thread overview: 14+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-10-27 22:58 [PATCH 0/4] Adjust t5411 for the upcoming change of the default branch name Johannes Schindelin via GitGitGadget
2020-10-27 22:58 ` Johannes Schindelin via GitGitGadget [this message]
2020-10-28 20:00   ` [PATCH 1/4] t5411: start using the default branch name "main" Junio C Hamano
2020-10-28 20:12     ` Junio C Hamano
2020-10-30 15:04       ` Johannes Schindelin
2020-10-30 17:06         ` Junio C Hamano
2020-10-27 22:58 ` [PATCH 2/4] t5411: start adjusting the support files for init.defaultBranch=main Johannes Schindelin via GitGitGadget
2020-10-27 22:58 ` [PATCH 3/4] t5411: adjust the remaining " Johannes Schindelin via GitGitGadget
2020-10-27 22:58 ` [PATCH 4/4] t5411: finish preparing for `main` being the default branch name Johannes Schindelin via GitGitGadget
2020-10-31 19:45 ` [PATCH v2 0/4] Adjust t5411 for the upcoming change of " Johannes Schindelin via GitGitGadget
2020-10-31 19:46   ` [PATCH v2 1/4] t5411: start using the default branch name "main" Johannes Schindelin via GitGitGadget
2020-10-31 19:46   ` [PATCH v2 2/4] t5411: start adjusting the support files for init.defaultBranch=main Johannes Schindelin via GitGitGadget
2020-10-31 19:46   ` [PATCH v2 3/4] t5411: adjust the remaining " Johannes Schindelin via GitGitGadget
2020-10-31 19:46   ` [PATCH v2 4/4] t5411: finish preparing for `main` being the default branch name Johannes Schindelin via GitGitGadget

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: http://vger.kernel.org/majordomo-info.html

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=f997166db4c29d971a2343f70c9d9a0505a8cc4b.1603839487.git.gitgitgadget@gmail.com \
    --to=gitgitgadget@gmail.com \
    --cc=git@vger.kernel.org \
    --cc=johannes.schindelin@gmx.de \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://80x24.org/mirrors/git.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).